@@ -9,27 +9,25 @@ from lightwood.mixers.helpers.ranger import Ranger
 from lightwood.encoders.categorical.onehot import OneHotEncoder
 from lightwood.api.gym import Gym
 from lightwood.config.config import CONFIG
+from lightwood.encoders.encoder_base import BaseEncoder
 
 
-MAX_LENGTH = 100
+class CategoricalAutoEncoder(BaseEncoder):
 
-
-class CategoricalAutoEncoder:
-
-    def __init__(self, is_target=False):
-        self._pytorch_wrapper = torch.FloatTensor
+    def __init__(self, is_target=False, max_encoded_length=100):
+        super().__init__(is_target)
         self._prepared = False
         self.name = 'Categorical Autoencoder'
         self.net = None
         self.encoder = None
         self.decoder = None
-        self.onehot_encoder = OneHotEncoder()
+        self.onehot_encoder = OneHotEncoder(is_target=self.is_target)
         self.desired_error = 0.01
         self.use_autoencoder = None
-        if is_target:
+        if self.is_target:
             self.max_encoded_length = None
         else:
-            self.max_encoded_length = 100
+            self.max_encoded_length = max_encoded_length
         self.max_training_time = 7200
 
     def _train_callback(self, error, real_buff, predicted_buff):
